'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _reactFormControlled = require('react-form-controlled');

var _reactFormControlled2 = _interopRequireDefault(_reactFormControlled);

var _Validator = require('./Validator');

var _Validator2 = _interopRequireDefault(_Validator);

var _Alert = require('./Alert');

var _Alert2 = _interopRequireDefault(_Alert);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Form', () => {
  it('should be able to create simple instance', done => {
    const value = {
      username: 'Zlatko'
    };

    const schema = {
      type: 'object',
      required: ['username', 'password'],
      properties: {
        username: {
          type: 'string',
          minLength: 2
        },
        password: {
          type: 'string',
          minLength: 2
        }
      }
    };

    let steps = 0;

    function onError(errors) {
      if (steps === 0) {
        expect(errors.length).toBe(1);
        expect(errors[0].path).toBe('password');
      }

      steps += 1;
    }

    function onSubmit(data) {
      expect(data.username).toBe('Zlatko');
      expect(data.password).toBe('test');
      expect(steps).toBe(2);
      done();
    }

    const wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _Validator2.default,
      { schema: schema },
      _react2.default.createElement(
        _reactFormControlled2.default,
        {
          value: value,
          onSubmit: onSubmit,
          onError: onError
        },
        _react2.default.createElement('input', { name: 'username' }),
        _react2.default.createElement(_Alert2.default, { name: 'password' }),
        _react2.default.createElement('input', { name: 'password' }),
        _react2.default.createElement(
          'button',
          { type: 'submit' },
          'Submit'
        )
      )
    ));

    expect(wrapper.find('form').length).toBe(1);
    wrapper.render().find('[type="submit"]').at(0).click();

    setTimeout(() => {
      const div = wrapper.render().find('div');
      expect(div.text()).toBe('should have required property \'password\'');
      steps++;
    }, 0);

    setTimeout(() => {
      expect(wrapper.find('input').length).toBe(2);
      wrapper.find('input').last().simulate('change', { target: {
          value: 'test'
        } });

      wrapper.render().find('[type="submit"]').at(0).click();
    }, 0);
  });
});
//# sourceMappingURL=Validator.test.js.map